@@ -10,7 +10,7 @@ gaussLegendre <- function(n, a, b) {
     i <- seq(1, n-1, by = 1)
     d <- i / sqrt(4*i^2 - 1)
 
-    E <- eigen(mdiag(d, 1) + mdiag(d, -1), symmetric = TRUE)
+    E <- eigen(Diag(d, 1) + Diag(d, -1), symmetric = TRUE)
     L <- E$values
     V <- E$vectors
 
@@ -32,7 +32,7 @@ gaussHermite <- function(n) {
     i <- seq(1, n-1, by = 1)
     d <- sqrt(i/2)
 
-    E <- eigen(mdiag(d, 1) + mdiag(d, -1), symmetric = TRUE)
+    E <- eigen(Diag(d, 1) + Diag(d, -1), symmetric = TRUE)
     L <- E$values
     V <- E$vectors
 
@@ -53,7 +53,7 @@ gaussLaguerre <- function(n, a = 0) {
     d <- (2*i - 1) + a
     b <- sqrt( i[1:(n-1)] * ((1:(n-1)) + a) )
 
-    E <- eigen(mdiag(d) + mdiag(b, 1) + mdiag(b, -1))
+    E <- eigen(Diag(d) + Diag(b, 1) + Diag(b, -1))
     L <- E$values
     V <- E$vectors
 
